//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[CommonShantenArgsValidationException](index.md)/[CommonShantenArgsValidationException](-common-shanten-args-validation-exception.md)

# CommonShantenArgsValidationException

[common]\
constructor(args: [CommonShantenArgs](../-common-shanten-args/index.md), errors: [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[CommonShantenArgsErrorInfo](../-common-shanten-args-error-info/index.md)&gt;)
